@@ -32,7 +32,7 @@
 # endif
 # include <limits.h>
 # include <stdio.h>      /* Needed before sys/mnttab.h in Solaris */
-# ifdef sun
+# if defined(sun)
 #  include <sys/mnttab.h>
 # elif __APPLE__
 #  include <sys/mount.h>
@@ -41,6 +41,9 @@
 # endif
 #include <signal.h>
 #endif
+#if defined(GLIBC_VERSION_24)
+#define _GNU_SOURCE
+#endif
 #include <unistd.h>
 #include <errno.h>
 #include <sys/stat.h>
@@ -48,7 +51,7 @@
 #include <stdlib.h>
 #include <fcntl.h>
 #include <dirent.h>
-#ifdef __linux__
+#if defined(__linux__)
 #   include <pwd.h>
 #endif
 
@@ -72,8 +75,7 @@ static char *FilePosixLookupMountPoint(char const *canPath, Bool *bind);
 #endif
 static char *FilePosixNearestExistingAncestor(char const *path);
 
-# ifdef VMX86_SERVER
-#define VMFS2CONST 456
+#if defined(VMX86_SERVER)
 #define VMFS3CONST 256
 #include "hostType.h"
 /* Needed for VMFS implementation of File_GetFreeSpace() */
@@ -81,7 +83,7 @@ static char *FilePosixNearestExistingAncestor(char const *path);
 # endif
 #endif
 
-#ifdef VMX86_SERVER
+#if defined(VMX86_SERVER)
 #include "fs_user.h"
 #endif
 
@@ -280,6 +282,20 @@ FileAttributes(ConstUnicode pathName,  // IN:
    int err;
    struct stat statbuf;
 
+#if defined(GLIBC_VERSION_24)
+   char *path;
+
+   if (fileData == NULL) {
+      if (!PosixConvertToCurrent(pathName, &path)) {
+         return -1;
+      }
+      ret = euidaccess(path, F_OK);
+      free(path);
+
+      return ret;
+   }
+#endif
+
    if (Posix_Stat(pathName, &statbuf) == -1) {
       err = errno;
    } else {
@@ -1034,7 +1050,7 @@ File_GetFreeSpace(ConstUnicode pathName,  // IN: File name
                   break;
                }
 
-               if ((statbuf.st_mode & S_IFMT) == S_IFDIR) {
+               if (S_ISDIR(statbuf.st_mode)) {
                   Warning(LGPFX" %s: directory (%s) present but inaccessible\n",
                           __func__, UTF8(fullPath));
                   errno = err;
@@ -1706,6 +1722,7 @@ FilePosixNearestExistingAncestor(char const *path) // IN: File path
 {
    size_t resultSize;
    char *result;
+   struct stat statbuf;
 
    resultSize = MAX(strlen(path), 1) + 1;
    result = Util_SafeMalloc(resultSize);
@@ -1719,7 +1736,7 @@ FilePosixNearestExistingAncestor(char const *path) // IN: File path
          break;
       }
 
-      if (File_Exists(result)) {
+      if (Posix_Stat(result, &statbuf) == 0) {
          break;
       }
 
@@ -2051,9 +2068,6 @@ FilePosixCreateTestFileSize(ConstUnicode dirName, // IN: directory to create lar
  *
  *      Check if the given file is on a VMFS supports such a file size
  *
- *      In the case of VMFS2, the largest supported file size is
- *         456 * 1024 * B bytes
- *
  *      In the case of VMFS3/4, the largest supported file size is
  *         256 * 1024 * B bytes
  *
@@ -2095,14 +2109,12 @@ File_VMFSSupportsFileSize(ConstUnicode pathName,  // IN:
    }
 
    if (strcmp(fsType, "VMFS") == 0) {
-      if (version == 2) {
-         maxFileSize = (VMFS2CONST * (uint64) blockSize * 1024);
-      } else if (version >= 3) {
+      if (version >= 3) {
          /* Get ready for VMFS4 and perform sanity check on version */
          ASSERT(version == 3 || version == 4);
 
          maxFileSize = (VMFS3CONST * (uint64) blockSize * 1024);
-      } 
+      }
 
       if (fileSize <= maxFileSize && maxFileSize != -1) {
          free(fsType);
