@@ -37,6 +37,10 @@
 
 #include "vix.h"
 #include "foundryThreads.h"
+#include "vixOpenSource.h"
+#include "str.h"
+#include "msg.h"
+
 
 #if _WIN32
 #include <objbase.h.> // For CoInitializeEx
@@ -44,8 +48,97 @@ static DWORD WINAPI FoundryThreadWrapperProc(LPVOID lpParameter);
 #else // Linux
 #include <pthread.h>
 static void *FoundryThreadWrapperProc(void *lpParameter);
+#if defined(linux)
+#include <sys/prctl.h>
+#endif
 #endif
 
+typedef void (*VixThreadFuncType)(void *);
+typedef void (*VixScheduleWorkFuncType)(VixThreadFuncType, void *);
+
+typedef struct IVixThread {
+   VixScheduleWorkFuncType ScheduleWorkFunc;
+} IVixThread;
+
+void Vix_SetExternalThreadInterface(IVixThread *threadInt);
+
+static void FoundryThreadWrapperWrapper(void *);
+
+static IVixThread *GlobalVixThreadInterface = NULL;
+
+static Bool GlobalEnableExternalThreadInterface = TRUE;
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * UseExternalThreadInterface --
+ *
+ *      Check if we should use the external thread interface
+ *
+ * Results:
+ *      None
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+Bool UseExternalThreadInterface(void)
+{
+   return GlobalEnableExternalThreadInterface &&
+      (GlobalVixThreadInterface != NULL);
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * VixThreadConfig --
+ *
+ *      Set whether to enable the use of external thread interface
+ *
+ * Results:
+ *      None
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void 
+VixThreadConfig(Bool enableExternalThreadInterface)
+{
+   GlobalEnableExternalThreadInterface = enableExternalThreadInterface;
+}
+
+
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * Vix_SetExternalThreadInterface --
+ *
+ *      Set the thread interface that foundry uses to schedule work item.
+ *      If the exnternal thread interface, foundry creates native thread
+ *      to run work item that may block.
+ *
+ * Results:
+ *      None
+ *
+ * Side effects:
+ *      None
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void
+Vix_SetExternalThreadInterface(IVixThread *threadInt) // IN
+{
+   ASSERT(threadInt->ScheduleWorkFunc);
+   GlobalVixThreadInterface = threadInt;
+} 
 
 /*
  *-----------------------------------------------------------------------------
@@ -64,10 +157,13 @@ static void *FoundryThreadWrapperProc(void *lpParameter);
 
 FoundryWorkerThread *
 FoundryThreads_StartThread(FoundryThreadProc proc,    // IN
-                           void *threadParam)         // IN
+                           void *threadParam,         // IN
+                           const char *threadName)    // IN
 {
    VixError err = VIX_OK;
    FoundryWorkerThread *threadState = NULL;
+   static const char *createThreadFailureMsg =
+      "%s: thread creation failed with error %d.\n";
 
    ASSERT(proc);
 
@@ -77,6 +173,13 @@ FoundryThreads_StartThread(FoundryThreadProc proc,    // IN
    threadState = (FoundryWorkerThread *) Util_SafeCalloc(1, sizeof(*threadState));
    threadState->threadProc = proc;
    threadState->threadParam = threadParam;
+   threadState->threadName = threadName;
+
+   if (UseExternalThreadInterface()) {
+      (*GlobalVixThreadInterface->ScheduleWorkFunc)(
+         FoundryThreadWrapperWrapper, threadState);
+      goto abort;
+   }
 
 #ifdef _WIN32
    threadState->threadHandle = CreateThread(NULL,
@@ -86,6 +189,7 @@ FoundryThreads_StartThread(FoundryThreadProc proc,    // IN
                                             0,
                                             &(threadState->threadId));
    if (NULL == threadState->threadHandle) {
+      Log(createThreadFailureMsg, __FUNCTION__, GetLastError());
       err = VIX_E_OUT_OF_MEMORY;
       goto abort;
    }
@@ -103,6 +207,7 @@ FoundryThreads_StartThread(FoundryThreadProc proc,    // IN
                               FoundryThreadWrapperProc, 
                               threadState);
       if (0 != result) {
+         Log(createThreadFailureMsg, __FUNCTION__, result);
          err = VIX_E_OUT_OF_MEMORY;
          goto abort;
       }
@@ -130,6 +235,7 @@ abort:
  *      None.
  *
  * Side effects:
+ *      May block while the given thread stops.
  *
  *-----------------------------------------------------------------------------
  */
@@ -137,33 +243,48 @@ abort:
 void
 FoundryThreads_StopThread(FoundryWorkerThread *threadState)    // IN
 {
+#ifdef _WIN32
+   DWORD waitResult;
+#endif
+
+   if (NULL == threadState) {
+      ASSERT(0);
+      return;
+   }
+
+   if (UseExternalThreadInterface()) {
+      /*
+       * It seems that if we got here the thread must have finished.
+       * Kill a thread in the middle of its running is a bad design
+       * by itself.
+       * Join a thread could block the poll thread, which is also bad.
+       * perhaps add a member in threadState to say "done", and
+       * assert on that.
+       */
+      FoundryThreads_Free(threadState);
+      return;
+   }
+
    /*
-    * Stop the poll thread.
+    * Stop the thread.
     */
    threadState->stopThread = TRUE;
 
-   if (NULL != threadState) {
+   ASSERT(!FoundryThreads_IsCurrentThread(threadState));
+
 #ifdef _WIN32
-      DWORD waitResult;
-
-      ASSERT(threadState->threadId != GetCurrentThreadId());
-
-      waitResult = WaitForSingleObject(threadState->threadHandle, 30000);
-      if (WAIT_OBJECT_0 != waitResult) {
-         TerminateThread(threadState->threadHandle, 0x1);
-      }
-
-      CloseHandle(threadState->threadHandle);
-      threadState->threadHandle = NULL;
-#else
-      pthread_join(threadState->threadInfo, NULL);
-      threadState->threadInfo = 0;
-#endif
+   waitResult = WaitForSingleObject(threadState->threadHandle, 30000);
+   if (WAIT_OBJECT_0 != waitResult) {
+      TerminateThread(threadState->threadHandle, 0x1);
    }
+#else
+   pthread_join(threadState->threadInfo, NULL);
+#endif
 
-   free(threadState);
+   FoundryThreads_Free(threadState);
 }
 
+
 /*
  *-----------------------------------------------------------------------------
  *
@@ -175,6 +296,7 @@ FoundryThreads_StopThread(FoundryWorkerThread *threadState)    // IN
  *      None.
  *
  * Side effects:
+ *      None.
  *
  *-----------------------------------------------------------------------------
  */
@@ -183,17 +305,21 @@ void
 FoundryThreads_Free(FoundryWorkerThread *threadState)    // IN
 {
    if (NULL != threadState) {
+      if (! UseExternalThreadInterface()) {
+
 #ifdef _WIN32
       CloseHandle(threadState->threadHandle);
       threadState->threadHandle = NULL;
 #else
       threadState->threadInfo = 0;
 #endif
+      }
+      
+      free(threadState);
    }
-
-   free(threadState);
 }
 
+
 /*
  *-----------------------------------------------------------------------------
  *
@@ -217,24 +343,38 @@ FoundryThreads_IsCurrentThread(struct FoundryWorkerThread *threadState)     // I
       return FALSE;
    }
 #ifdef _WIN32
-   {
-      Util_ThreadID id = GetCurrentThreadId();
-      if (id == threadState->threadId) {
-	 return TRUE;
-      }
-   }
+   return (GetCurrentThreadId() == threadState->threadId);
 #else
-   {
-      pthread_t id = pthread_self();
-      if (pthread_equal(id, threadState->threadInfo)) {
-	 return TRUE;
-      }
-   }
+   return pthread_equal(pthread_self(), threadState->threadInfo);
 #endif
-   return FALSE;
 }
 
 
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * FoundryThreadWrapperWrapper --
+ *
+ *      Adaptor function to help schedule work item.
+ *      Since we are not using the return result in FoundryThreadWrapperProc.
+ *      and hostd thread interface cannot provide a return result.
+ *      so we just discard the return result.
+ *
+ * Results:
+ *      None.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void
+FoundryThreadWrapperWrapper(void *data)
+{
+   FoundryThreadWrapperProc(data);
+}
+
 /*
  *-----------------------------------------------------------------------------
  *
@@ -263,10 +403,31 @@ FoundryThreadWrapperProc(void *threadParameter)      // IN
 
    threadState = (FoundryWorkerThread *) threadParameter;
    if (NULL == threadState) {
+      ASSERT(0);
       goto abort;
    }
-   
-   if (NULL != threadState) {
+#if defined(linux) && defined(PR_SET_NAME)
+   {
+      char threadName[64];
+      int retval;
+      Str_Sprintf(threadName, sizeof threadName, "vix-%s", threadState->threadName);
+      retval = prctl(PR_SET_NAME, (unsigned long)threadName, 0,0, 0);
+
+      /*
+       * XXX: VIX_DEBUG() uses symbols which aren't part of the open-sourced
+       * VIX code. The symbols reside in vixDebug.c, which uses our internal
+       * vixSemiPublic.h. This code is never really used in the guest, so,
+       * other than being ugly, it's OK to do this.
+       */
+#if !defined(OPEN_VM_TOOLS)
+      if (retval != 0) {
+         VIX_DEBUG(("%s prctl PR_SET_NAME failed = %s\n", __FUNCTION__, Msg_ErrString()));
+      }
+#endif
+   }
+#endif
+
+   if (NULL != threadState->threadProc) {
       (*(threadState->threadProc))(threadState);
    }
 
