@@ -32,7 +32,6 @@ extern "C" {
 #include <string.h>
 
 #include "vmware.h"
-#include "vm_app.h"
 #include "vm_version.h"
 #include "vm_tools_version.h"
 #include "guestApp.h"
@@ -50,12 +49,11 @@ extern "C" {
 #include "codeset.h"
 #include "productState.h"
 #include "posix.h"
+#include "vmware/guestrpc/tclodefs.h"
 
-#if !defined(N_PLAT_NLM)
-# include "hgfs.h"
-# include "cpName.h"
-# include "cpNameUtil.h"
-#endif
+#include "hgfs.h"
+#include "cpName.h"
+#include "cpNameUtil.h"
 
 #ifdef _MSC_VER
 #include <windows.h>
@@ -71,9 +69,7 @@ extern "C" {
  * intelligent for that platform as well.
  */
 
-#if defined(N_PLAT_NLM)
-#define GUESTAPP_TOOLS_INSTALL_PATH "SYS:\\ETC\\VMWTOOL"
-#elif defined(_WIN32)
+#if defined(_WIN32)
 #define GUESTAPP_TOOLS_INSTALL_PATH ""
 #else
 #define GUESTAPP_TOOLS_INSTALL_PATH "/etc/vmware-tools"
@@ -442,7 +438,7 @@ GuestApp_GetDictEntryBool(GuestApp_Dict *dict, // IN
       return FALSE;
    }
 
-#if  (defined N_PLAT_NLM || defined _WIN32)
+#if defined (_WIN32)
    return (stricmp(value, "TRUE") == 0);
 #else
    return (strcasecmp(value, "TRUE") == 0);
@@ -1644,7 +1640,6 @@ GuestApp_HostCopyStep(uint8 c) // IN
 }
 
 
-#if !defined(N_PLAT_NLM)
 /*
  *----------------------------------------------------------------------------
  *
@@ -1792,35 +1787,6 @@ GuestApp_RpcSendOneCPName(char const *cmd,  // IN: RPCI command
    free(rpcMessage);
    return TRUE;
 }
-#endif
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * GuestApp_ControlRecord --
- *
- *    Start or stop recording process, flagged by command. 
- *    Command definition is in statelogger_backdoor_def.h.
- *
- * Results:
- *    TRUE on success and FALSE on failure.
- *
- * Side effects:
- *    Host VMware product starts or stops recording this vm.
- *
- *-----------------------------------------------------------------------------
- */
-
-Bool
-GuestApp_ControlRecord(int32 command) // IN: flag of starting or stopping recording
-{
-   Backdoor_proto bp;
-   bp.in.size = command;
-   bp.in.cx.halfs.low = BDOOR_CMD_STATELOGGER;
-   Backdoor(&bp);
-   return (bp.out.ax.halfs.low == 1);
-}
 
 #ifdef __cplusplus
 }
