@@ -93,7 +93,7 @@
 #define BDOOR_CMD_GETUUID               19
 #define BDOOR_CMD_GETMEMSIZE            20
 #define BDOOR_CMD_HOSTCOPY              21 /* Devel only */
-#define BDOOR_CMD_SERVICE_VM            22 /* prototype only */         
+#define BDOOR_CMD_SERVICE_VM            22 /* Unused, never shipped, prototype only */         
 #define BDOOR_CMD_GETTIME               23 /* Deprecated. Use GETTIMEFULL. */
 #define BDOOR_CMD_STOPCATCHUP           24
 #define BDOOR_CMD_PUTCHR	        25 /* Devel only */
@@ -134,7 +134,10 @@
 #define BDOOR_CMD_GET_HOST_VIDEO_MODES  59 /* Not in use */
 #define BDOOR_CMD_ACPI_HOTPLUG_CPU      60
 #define BDOOR_CMD_USB_HOTPLUG_MOUSE     61 /* Not in use */
-#define BDOOR_CMD_MAX                   62
+#define BDOOR_CMD_XPMODE                62
+#define BDOOR_CMD_NESTING_CONTROL       63
+#define BDOOR_CMD_FIRMWARE_INIT         64
+#define BDOOR_CMD_MAX                   65
 
 
 /* 
@@ -144,6 +147,13 @@
  * the registers. Otherwise backwards compatibility will suffer.
  */
 
+/* Nesting control operations */
+
+#define NESTING_CONTROL_ENTER_VMM        0
+#define NESTING_CONTROL_EXIT_VMM         1
+#define NESTING_CONTROL_QUERY            2
+#define NESTING_CONTROL_MAX              2
+
 /* High-bandwidth backdoor port. --hpreg */
 
 #define BDOORHB_PORT 0x5659
@@ -161,6 +171,7 @@
 #define BDOOR_PMC_HW_TSC      0x10000
 #define BDOOR_PMC_REAL_NS     0x10001
 #define BDOOR_PMC_APPARENT_NS 0x10002
+#define BDOOR_PMC_PSEUDO_TSC  0x10003
 
 #define IS_BDOOR_PMC(index)  (((index) | 3) == 0x10003)
 #define BDOOR_CMD(ecx)       ((ecx) & 0xffff)
