@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2009-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2009 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -40,14 +40,16 @@
 #define _COMMUNITY_SOURCE_H_
 
 #define INCLUDE_ALLOW_USERLEVEL
-
+#define INCLUDE_ALLOW_VMMEXT
 #define INCLUDE_ALLOW_MODULE
 #define INCLUDE_ALLOW_VMMON
+#define INCLUDE_ALLOW_VMNIXMOD
 #define INCLUDE_ALLOW_VMKERNEL
 #define INCLUDE_ALLOW_VMKDRIVERS
 #define INCLUDE_ALLOW_VMK_MODULE
 #define INCLUDE_ALLOW_DISTRIBUTE
 #define INCLUDE_ALLOW_VMCORE
+#define INCLUDE_ALLOW_VMIROM
 #include "includeCheck.h"
 
 /* 
@@ -60,19 +62,10 @@
    #define EXCLUDE_COMMUNITY_SOURCE(x) x
 #endif
 
-#undef COMMUNITY_SOURCE_AMD_SECRET
-#if !defined(COMMUNITY_SOURCE) || defined(AMD_SOURCE)
-/*
- * It's ok to include AMD_SECRET source code for non-Community Source,
- * or for drops directed at AMD.
- */
-   #define COMMUNITY_SOURCE_AMD_SECRET
-#endif
-
 #undef COMMUNITY_SOURCE_INTEL_SECRET
 #if !defined(COMMUNITY_SOURCE) || defined(INTEL_SOURCE)
 /*
- * It's ok to include INTEL_SECRET source code for non-Community Source,
+ * It's ok to include INTEL_SECRET source code for non-commsrc,
  * or for drops directed at Intel.
  */
    #define COMMUNITY_SOURCE_INTEL_SECRET
