@@ -30,18 +30,9 @@
 
 #include "guestApp.h"
 
-#ifdef N_PLAT_NLM
-#define CONF_FILE         "tools.cfg"
-#else
 #define CONF_FILE         "tools.conf"
-#endif
 
-#ifdef N_PLAT_NLM
-#   define CONFVAL_POWERONSCRIPT_DEFAULT  "POWERON.NCF"
-#   define CONFVAL_POWEROFFSCRIPT_DEFAULT "POWEROFF.NCF"
-#   define CONFVAL_RESUMESCRIPT_DEFAULT   "RESUME.NCF"
-#   define CONFVAL_SUSPENDSCRIPT_DEFAULT  "SUSPEND.NCF"
-#elif ! defined(_WIN32)
+#if ! defined(_WIN32)
 #   define CONFVAL_POWERONSCRIPT_DEFAULT  "poweron-vm-default"
 #   define CONFVAL_POWEROFFSCRIPT_DEFAULT "poweroff-vm-default"
 #   define CONFVAL_RESUMESCRIPT_DEFAULT   "resume-vm-default"
@@ -61,8 +52,40 @@
 #define CONFNAME_LOG                      "log"
 #define CONFNAME_LOGFILE                  "log.file"
 #define CONFNAME_LOGLEVEL                 "log.level" 
-#define CONFNAME_DISABLEQUERYDISKINFO     "disable-query-diskinfo"
 #define CONFNAME_DISABLETOOLSVERSION      "disable-tools-version"
+#define CONFNAME_DISABLEPMTIMERWARNING    "disable-pmtimerwarning"
+
+
+/*
+ ******************************************************************************
+ * BEGIN GuestInfo goodies.
+ */
+
+/**
+ * Defines the string used for the GuestInfo config file group.
+ */
+#define CONFGROUPNAME_GUESTINFO "guestinfo"
+
+/**
+ * Lets users disable just DiskInfo.
+ */
+#define CONFNAME_GUESTINFO_DISABLEQUERYDISKINFO "disable-query-diskinfo"
+
+/**
+ * Define a custom GuestInfo poll interval (in seconds).
+ *
+ * @note Illegal values result in a @c g_warning and fallback to the default
+ * poll interval.
+ *
+ * @param int   User-defined poll interval.  Set to 0 to disable polling.
+ */
+#define CONFNAME_GUESTINFO_POLLINTERVAL "poll-interval"
+
+/*
+ * END GuestInfo goodies.
+ ******************************************************************************
+ */
+
 
 /*
  * Tell the tools to show the wireless icon in the guest.
@@ -74,7 +97,7 @@
  * Directory containing the tools library files.  Currently only intended
  * for vmware-user.
  */
-#if !defined(_WIN32) && !defined(N_PLAT_NLM)
+#if !defined(_WIN32)
 #   define CONFNAME_LIBDIR                        "libdir"
 #endif
 
