@@ -49,12 +49,6 @@ char *System_GetEnv(Bool global, const char *valueName);
 int System_SetEnv(Bool global, const char *valueName, const char *value);
 
 #ifdef _WIN32
-typedef void (*DesktopSwitchNotifyCB)(void *);
-typedef struct {
-   DesktopSwitchNotifyCB cb;   // callback to invoke.
-   void *cbdata;               // data to pass to callback
-} DesktopSwitchThreadArgs;
-
 /*
  * Representation of monitors gathered by System_GetMonitors.
  */
@@ -64,6 +58,7 @@ typedef struct MonListNode {
    BOOL isPrimary;
    DWORD bpp;
    BOOL isActive;
+   uint32 srcId;
    DblLnkLst_Links l;
 } MonListNode;
 
@@ -81,11 +76,11 @@ Bool System_IsLoginScreenActive(void);
 Bool System_IsProcessElevated(void);
 Bool System_IsScreenSaverActive(void);
 Bool System_IsScreenSaverRunning(void);
-Bool System_StartDesktopSwitchThread(DesktopSwitchThreadArgs *args);
-Bool System_KillDesktopSwitchThread(void);
+Bool System_IsSecureDesktopActive(void);
 Bool System_DisableAndKillScreenSaver(void);
 DWORD System_GetServiceState(LPCWSTR szServiceName);
 DblLnkLst_Links *System_GetMonitors();
+void System_SetFocusedWindow(HWND windowToFocus, Bool force);
 #endif
 
 
@@ -95,7 +90,7 @@ DblLnkLst_Links *System_GetMonitors();
  *        then acted upon and translates to a -DPOSIX_LIKE_ENVIRONMENT
  *        preprocessor option.
  */
-#if !defined(_WIN32) && !defined(N_PLAT_NLM)
+#if !defined(_WIN32)
 Bool System_WritePidFile(const char *fileName, pid_t pid);
 const char **System_GetNativeEnviron(const char **compatEnviron);
 void System_FreeNativeEnviron(const char **nativeEnviron);
