@@ -87,10 +87,11 @@
 
 #if defined _WIN32 && defined USERLEVEL
    #include <stddef.h>  /*
-                         * We re-define offsetof macro from stddef, make 
-                         * sure that its already defined before we do it
+                         * We redefine offsetof macro from stddef; make 
+                         * sure that it's already defined before we do that.
                          */
    #include <windows.h>	// for Sleep() and LOWORD() etc.
+   #undef GetFreeSpace  // Unpollute preprocessor namespace.
 #endif
 
 
@@ -160,8 +161,8 @@ Max(int a, int b)
 
 #define MASK(n)			((1 << (n)) - 1)	/* make an n-bit mask */
 
-#define DWORD_ALIGN(x)          ((((x)+3) >> 2) << 2)
-#define QWORD_ALIGN(x)          ((((x)+4) >> 3) << 3)
+#define DWORD_ALIGN(x)          ((((x) + 3) >> 2) << 2)
+#define QWORD_ALIGN(x)          ((((x) + 7) >> 3) << 3)
 
 #define IMPLIES(a,b) (!(a) || (b))
 
@@ -209,6 +210,8 @@ Max(int a, int b)
    #define PAGE_SHIFT    12
 #elif defined __APPLE__
    #define PAGE_SHIFT    12
+#elif defined __arm__
+   #define PAGE_SHIFT    12
 #else
    #error
 #endif
@@ -604,6 +607,12 @@ typedef int pid_t;
 #define POSIX_ONLY(x) x
 #endif
 
+#ifdef __linux__
+#define LINUX_ONLY(x) x
+#else
+#define LINUX_ONLY(x)
+#endif
+
 #ifdef VMM
 #define VMM_ONLY(x) x
 #define USER_ONLY(x)
@@ -657,40 +666,4 @@ typedef int pid_t;
 #define hosted_lg_pg 0
 #endif
 
-/*
- ***********************************************************************
- * STRUCT_OFFSET_CHECK --                                    */ /**
- *
- * \brief Check if the actual offsef of a member in a structure
- *        is what is expected
- *
- *
- * \param[in]  STRUCT       Structure the member is a part of.
- * \param[in]  MEMBER       Member to check the offset of.
- * \param[in]  OFFSET       Expected offset of MEMBER in STRUCTURE.
- * \param[in]  EXTRA        Additional bytes to be added to OFFSET to
- *                          compensate for extra info (eg. debug info)
- *
- ***********************************************************************
- */
-#define STRUCT_OFFSET_CHECK(STRUCT, MEMBER, OFFSET, EXTRA) \
-  ASSERT_ON_COMPILE(vmk_offsetof(STRUCT, MEMBER) == (OFFSET + EXTRA))
-
-/*
- ***********************************************************************
- * STRUCT_SIZE_CHECK --                                      */ /**
- *
- * \brief Check if the actual size of a structure is what is expected
- *
- *
- * \param[in]  STRUCT       Structure whose size is to be checked.
- * \param[in]  SIZE         Expected size of STRUCT.
- * \param[in]  EXTRA        Additional bytes to be added to SIZE to
- *                          compensate for extra info (eg. debug info)
- *
- ***********************************************************************
- */
-#define STRUCT_SIZE_CHECK(STRUCT, SIZE, EXTRA) \
-  ASSERT_ON_COMPILE(sizeof(STRUCT) == (SIZE + EXTRA))
-
 #endif // ifndef _VM_BASIC_DEFS_H_
