@@ -900,6 +900,13 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_WS70_RC_V_MNR  1
 #define   TOOLS_VERSION_WS70_RC_V_BASE 2
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_WS70_RELEASE  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_WS70_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_WS70_RELEASE_V_MJR  8
+#define   TOOLS_VERSION_WS70_RELEASE_V_MNR  1
+#define   TOOLS_VERSION_WS70_RELEASE_V_BASE 3
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_FUSION30_BETA1  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_FUSION30_BETA1_V)
 #endif /* RC_INVOKED */
@@ -921,9 +928,23 @@ typedef uint32 ToolsVersion;
 #define   TOOLS_VERSION_FUSION30_RC_V_MNR  2
 #define   TOOLS_VERSION_FUSION30_RC_V_BASE 2
 
-#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_WS70_RC
-#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_WS70_RC)
-#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_WS70_RC)
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_FUSION30_RELEASE  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_FUSION30_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_FUSION30_RELEASE_V_MJR  8
+#define   TOOLS_VERSION_FUSION30_RELEASE_V_MNR  2
+#define   TOOLS_VERSION_FUSION30_RELEASE_V_BASE 3
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_ESX45_BETA1  TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX45_BETA1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_ESX45_BETA1_V_MJR  8
+#define   TOOLS_VERSION_ESX45_BETA1_V_MNR  3
+#define   TOOLS_VERSION_ESX45_BETA1_V_BASE 0
+
+#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_ESX45_BETA1
+#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_ESX45_BETA1)
+#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_ESX45_BETA1)
 
 
 /*
