@@ -1,6 +1,5 @@
 /*********************************************************
- * Copyright (c) 2008-2024 Broadcom. All Rights Reserved.
- * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
+ * Copyright (C) 2008 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -18,7 +17,7 @@
  *********************************************************/
 
 /*
- * capabilities.h --
+ * guestCaps.h --
  *
  *  Common definitions for the guestCaps system that allows a guest to
  *  register an arbitrary number of boolean capabilites with the vmx.
@@ -27,27 +26,17 @@
 #ifndef _GUEST_CAPS_H_
 #define _GUEST_CAPS_H_
 
-/* clang-format off */
 /*
  * Guest capabilities.
- *
  * The guest uses this enum to communicate whether a certain
  * feature is supported by the tools.
- *
  * The guest sends an RPC where it specifies which features
- * are turned off and on, for example:
- *
- * "tools.capability.features 0=1 2=1 3=0"
- *
+ * are turned off and on, for example
+ * "tools.capability.features 0=1 2=1 3=0".
  * In the above example, the guest is capable of showing the
  * start menu and setting the work area, but does not support
  * multiple monitors.
  *
- * For capabilities that can be managed by tools.conf settings, guest should
- * send a separate RPC tools.capability.features for each capability change,
- * even when multiple such capabilities are changed by tools.conf at the same
- * time.
- *
  * NOTE: the order for these has to stay constant for backward compatibility
  * with older Tools versions. New capabilities must be added at the end.
  */
@@ -70,7 +59,9 @@ typedef enum {
    GHI_CAP_SET_HANDLER                  = 14, // supports setting the handler for types/protocols
    UNITY_CAP_STATUS_UNITY_ACTIVE        = 15, // supports GuestRpc bits for Unity Status
    GHI_CAP_SET_OUTLOOK_TEMP_FOLDER      = 16, // supports setting the Outlook temp folder
-                                              // 17 is obsolete, do not use
+   GHI_CAP_TRASH_FOLDER                 = 17, // supports ghi.guest.trashFolder.action,
+                                              // ghi.guest.trashFolder.state, and
+                                              // ghi.guest.trashFolder.getIcon commands
    CAP_SET_TOPO_MODES                   = 18, // supports setting topology modes in video driver
    GHI_CAP_TRAY_ICONS                   = 19, // supports ghi.guest.trayIcon commands
    GHI_CAP_SET_FOCUSED_WINDOW           = 20, // supports ghi.guest.setFocusedWindow
@@ -78,19 +69,6 @@ typedef enum {
    UNITY_CAP_STICKY_WINDOWS             = 22, // supports unity.window.{un,}stick
    CAP_CHANGE_HOST_3D_AVAILABILITY_HINT = 23, // supports sending 3D support hint to guest
    CAP_AUTOUPGRADE_AT_SHUTDOWN          = 24, // supports auto-upgrading tools at OS shutdown
-   GHI_CAP_AUTOLOGON                    = 25, // supports autologon
-   CAP_DESKTOP_AUTOLOCK                 = 26, // supports desktop autolock
-                                              // 27 is obsolete, do not use
-   HGFSU_CAP_MIRROR_DOWNLOADS           = 28, // supports remapping GOS Downloads to HGFS
-   HGFSU_CAP_MIRROR_MOVIES              = 29, // supports remapping GOS Movies to HGFS
-   GHI_CAP_TOGGLE_START_UI              = 30, // supports showing/hiding the Start UI
-   GHI_CAP_SET_DISPLAY_SCALING          = 31, // supports setting the display scaling (DPI)
-   UNITY_CAP_DISABLE_MOUSE_BUTTON_SWAPPING     = 32, // supports disabling mouse button swapping
-   UNITY_CAP_CARET_POSITION             = 33, // supports sending caret position updates
-   CAP_GUESTSTORE_UPGRADE               = 34, // supports tools upgrade from GuestStore
-   CAP_DEVICE_HELPER                    = 35, // supports tools device helper for Windows guests
-   CAP_VMBACKUP_NVME                    = 36, // supports NVMe for vmbackup
-   CAP_HOST_VERIFIED_SAML_TOKEN         = 37, // supports host verification of SAML tokens
 } GuestCapabilities;
 
 typedef struct {
@@ -114,6 +92,21 @@ typedef struct {
  * If you change these strings, make sure you also change the
  *  vmdb schema, since these strings are used as vmdb keys.
  */
+
+/*
+ * This table must be sorted such that it can be indexed using the
+ * GuestCapabilities enum above. RPC calls pass the value, and the
+ * handler code uses it as an index. In other words, the value of the
+ * caps field at index i must be equal to i as well. This is because
+ * the code that looks up entries in this table assume as much. It
+ * also means we don't need the cap field, or, to justify its existence,
+ * the lookup code should be converted to loop through the table and
+ * return the entry where cap == the value passed in the RPC call.
+ * Moral of the story, new entries always at the bottom of the table
+ * and the cap field must be set to the offset in the array (and make
+ * sure the enum in GuestCapabilities is also set to that offset).
+ */
+
 static GuestCapElem guestCapTable[] = {
    { UNITY_CAP_START_MENU,                 UNITY_CAP_VMDB_PATH, "startmenu" },
    { UNITY_CAP_VIRTUAL_DESK,               UNITY_CAP_VMDB_PATH, "virtualdesk" },
@@ -134,31 +127,15 @@ static GuestCapElem guestCapTable[] = {
    { GHI_CAP_SET_HANDLER,                  GHI_CAP_VMDB_PATH,   "setHandler" },
    { UNITY_CAP_STATUS_UNITY_ACTIVE,        UNITY_CAP_VMDB_PATH, "unityActive" },
    { GHI_CAP_SET_OUTLOOK_TEMP_FOLDER,      GHI_CAP_VMDB_PATH,   "setOutlookTempFolder" },
-   { CAP_SET_TOPO_MODES,                   CAP_VMDB_PATH,       "displayTopologyModesSet" },
+   { GHI_CAP_TRASH_FOLDER,                 GHI_CAP_VMDB_PATH,   "trashFolder" },
+   { CAP_SET_TOPO_MODES,                   CAP_VMDB_PATH, "displayTopologyModesSet" },
    { GHI_CAP_TRAY_ICONS,                   GHI_CAP_VMDB_PATH,   "trayIcons" },
    { GHI_CAP_SET_FOCUSED_WINDOW,           GHI_CAP_VMDB_PATH,   "setFocusedWindow"},
    { GHI_CAP_GET_EXEC_INFO_HASH,           GHI_CAP_VMDB_PATH,   "getExecInfoHash"},
    { UNITY_CAP_STICKY_WINDOWS,             UNITY_CAP_VMDB_PATH, "sticky"},
-   { CAP_CHANGE_HOST_3D_AVAILABILITY_HINT, CAP_VMDB_PATH,       "changeHost3DAvailabilityHint" },
+   { CAP_CHANGE_HOST_3D_AVAILABILITY_HINT, CAP_VMDB_PATH, "changeHost3DAvailabilityHint" },
    { CAP_AUTOUPGRADE_AT_SHUTDOWN,          CAP_VMDB_PATH,       "autoUpgradeAtShutdown"},
-   { GHI_CAP_AUTOLOGON,                    GHI_CAP_VMDB_PATH,   "autologon" },
-   { CAP_DESKTOP_AUTOLOCK,                 CAP_VMDB_PATH,       "desktopAutolock" },
-   { HGFSU_CAP_MIRROR_DOWNLOADS,           HGFSU_CAP_VMDB_PATH, "mirrorDownloads" },
-   { HGFSU_CAP_MIRROR_MOVIES,              HGFSU_CAP_VMDB_PATH, "mirrorMovies" },
-   { GHI_CAP_TOGGLE_START_UI,              GHI_CAP_VMDB_PATH,   "toggleStartUI"},
-   { GHI_CAP_SET_DISPLAY_SCALING,          GHI_CAP_VMDB_PATH,   "setDisplayScaling"},
-   { UNITY_CAP_DISABLE_MOUSE_BUTTON_SWAPPING, UNITY_CAP_VMDB_PATH, "mouseButtonSwapping" },
-   { UNITY_CAP_CARET_POSITION,             UNITY_CAP_VMDB_PATH, "getCaretPosition" },
-   /*
-    * GuestStoreUpgrade is available on ESXi only at this time. Therefore, we
-    * don't define VMDB schema for it and don't store it in VMDB.
-    */
-   { CAP_GUESTSTORE_UPGRADE,               NULL,                NULL },
-   { CAP_DEVICE_HELPER,                    NULL,                NULL },
-   { CAP_VMBACKUP_NVME,                    NULL,                NULL },
-   { CAP_HOST_VERIFIED_SAML_TOKEN,         NULL,                NULL },
 };
-// clang-format on
 
 #endif // VM_NEED_VMDB_GUEST_CAP_MAPPING
 
