@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2003-2015 VMware, Inc. All rights reserved.
+ * Copyright (C) 2003-2009 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -33,16 +33,17 @@
 /*
  * x86cpuid_asm.h
  *
- *      CPUID-related assembly functions.
+ *	CPUID-related assembly functions.
  */
 
 #ifndef _X86CPUID_ASM_H_
 #define _X86CPUID_ASM_H_
 
 #define INCLUDE_ALLOW_USERLEVEL
-
+#define INCLUDE_ALLOW_VMMEXT
 #define INCLUDE_ALLOW_MODULE
 #define INCLUDE_ALLOW_VMMON
+#define INCLUDE_ALLOW_VMNIXMOD
 #define INCLUDE_ALLOW_VMK_MODULE
 #define INCLUDE_ALLOW_VMKERNEL
 #define INCLUDE_ALLOW_DISTRIBUTE
@@ -60,10 +61,10 @@
  * an array of the names of all the intrinsics minus the leading
  * underscore.  Searching around in the ntddk.h file can also be helpful.
  *
- * The declarations for the intrinsic functions were taken from the DDK.
+ * The declarations for the intrinsic functions were taken from the DDK. 
  * Our declarations must match the ddk's otherwise the 64-bit c++ compiler
  * will complain about second linkage of the intrinsic functions.
- * We define the intrinsic using the basic types corresponding to the
+ * We define the intrinsic using the basic types corresponding to the 
  * Windows typedefs. This avoids having to include windows header files
  * to get to the windows types.
  */
@@ -75,7 +76,7 @@ extern "C" {
 /*
  * intrinsic functions only supported by x86-64 windows as of 2k3sp1
  */
-void __cpuid(int regs[4], int eax);
+void             __cpuid(unsigned int*, unsigned int);
 #pragma intrinsic(__cpuid)
 #endif /* VM_X86_64 */
 
@@ -89,48 +90,26 @@ void __cpuid(int regs[4], int eax);
 
 /*
  * Checked against the Intel manual and GCC --hpreg
- *
+ * 
  * Need __volatile__ and "memory" since CPUID has a synchronizing effect.
  * The CPUID may also change at runtime (APIC flag, etc).
  *
  */
 
-/*
- * %ebx is reserved on i386 PIC.  Apple's gcc-5493 (gcc 4.0) compiling
- * for x86_64 incorrectly errors out saying %ebx is reserved.  This is
- * Apple bug 7304232.
- */
-#if vm_x86_64 ? (defined __APPLE_CC__ && __APPLE_CC__ == 5493) : defined __PIC__
-#if vm_x86_64
-/*
- * Note that this generates movq %rbx,%rbx; cpuid; xchgq %rbx,%rbx ...
- * Unfortunately Apple's assembler does not have .ifnes, and I cannot
- * figure out how to do that with .if.   If we ever enable this code
- * on other 64bit systems, both movq & xchgq should be surrounded by
- * .ifnes \"%%rbx\", \"%q1\" & .endif
- */
-#define VM_CPUID_BLOCK  "movq %%rbx, %q1\n\t" \
-                        "cpuid\n\t"           \
-                        "xchgq %%rbx, %q1\n\t"
-#define VM_EBX_OUT(reg) "=&r"(reg)
-#else
-#define VM_CPUID_BLOCK  "movl %%ebx, %1\n\t" \
-                        "cpuid\n\t"          \
-                        "xchgl %%ebx, %1\n\t"
-#define VM_EBX_OUT(reg) "=&rm"(reg)
-#endif
-#else
-#define VM_CPUID_BLOCK  "cpuid"
-#define VM_EBX_OUT(reg) "=b"(reg)
-#endif
-
 static INLINE void
 __GET_CPUID(int eax,         // IN
             CPUIDRegs *regs) // OUT
 {
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (regs->eax), VM_EBX_OUT(regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (regs->eax), "=&rm" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#else
+      "cpuid"
+      : "=a" (regs->eax), "=b" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#endif
       : "a" (eax)
       : "memory"
    );
@@ -142,8 +121,15 @@ __GET_CPUID2(int eax,         // IN
              CPUIDRegs *regs) // OUT
 {
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (regs->eax), VM_EBX_OUT(regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (regs->eax), "=&rm" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#else
+      "cpuid"
+      : "=a" (regs->eax), "=b" (regs->ebx), "=c" (regs->ecx), "=d" (regs->edx)
+#endif
       : "a" (eax), "c" (ecx)
       : "memory"
    );
@@ -152,14 +138,25 @@ __GET_CPUID2(int eax,         // IN
 static INLINE uint32
 __GET_EAX_FROM_CPUID(int eax) // IN
 {
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx)
       : "a" (eax)
       : "memory", "%ecx", "%edx"
    );
+#else
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax)
+      : "a" (eax)
+      : "memory", "%ebx", "%ecx", "%edx"
+   );
+#endif
 
    return eax;
 }
@@ -170,8 +167,15 @@ __GET_EBX_FROM_CPUID(int eax) // IN
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx)
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx)
+#else
+      "cpuid"
+      : "=a" (eax), "=b" (ebx)
+#endif
       : "a" (eax)
       : "memory", "%ecx", "%edx"
    );
@@ -183,14 +187,26 @@ static INLINE uint32
 __GET_ECX_FROM_CPUID(int eax) // IN
 {
    uint32 ecx;
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx), "=c" (ecx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx), "=c" (ecx)
       : "a" (eax)
       : "memory", "%edx"
    );
+#else
+
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax), "=c" (ecx)
+      : "a" (eax)
+      : "memory", "%ebx", "%edx"
+   );
+#endif
 
    return ecx;
 }
@@ -199,14 +215,26 @@ static INLINE uint32
 __GET_EDX_FROM_CPUID(int eax) // IN
 {
    uint32 edx;
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx), "=d" (edx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx), "=d" (edx)
       : "a" (eax)
       : "memory", "%ecx"
    );
+#else
+
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax), "=d" (edx)
+      : "a" (eax)
+      : "memory", "%ebx", "%ecx"
+   );
+#endif
 
    return edx;
 }
@@ -216,28 +244,37 @@ static INLINE uint32
 __GET_EAX_FROM_CPUID4(int ecx) // IN
 {
    uint32 eax;
+#if defined __PIC__ && !vm_x86_64 // %ebx is reserved by the compiler.
    uint32 ebx;
 
    __asm__ __volatile__(
-      VM_CPUID_BLOCK
-      : "=a" (eax), VM_EBX_OUT(ebx), "=c" (ecx)
+      "movl %%ebx, %1"  "\n\t"
+      "cpuid"           "\n\t"
+      "xchgl %%ebx, %1"
+      : "=a" (eax), "=&rm" (ebx), "=c" (ecx)
       : "a" (4), "c" (ecx)
       : "memory", "%edx"
    );
+#else
+
+   __asm__ __volatile__(
+      "cpuid"
+      : "=a" (eax), "=c" (ecx)
+      : "a" (4), "c" (ecx)
+      : "memory", "%ebx", "%edx"
+   );
+#endif
 
    return eax;
 }
 
-#undef VM_CPUID_BLOCK
-#undef VM_EBX_OUT
-
 #elif defined(_MSC_VER) // } {
 
 static INLINE void
 __GET_CPUID(int input, CPUIDRegs *regs)
 {
 #ifdef VM_X86_64
-   __cpuid((int *)regs, input);
+   __cpuid((unsigned int *)regs, input);
 #else
    __asm push esi
    __asm push ebx
@@ -262,7 +299,7 @@ __GET_CPUID(int input, CPUIDRegs *regs)
 #ifdef VM_X86_64
 
 /*
- * No inline assembly in Win64. Implemented in bora/lib/misc in
+ * No inline assembly in Win64. Implemented in bora/lib/user in
  * cpuidMasm64.asm.
  */
 
@@ -300,7 +337,7 @@ __GET_EAX_FROM_CPUID(int input)
 {
 #ifdef VM_X86_64
    CPUIDRegs regs;
-   __cpuid((int *)&regs, input);
+   __cpuid((unsigned int *)&regs, input);
    return regs.eax;
 #else
    uint32 output;
@@ -327,7 +364,7 @@ __GET_EBX_FROM_CPUID(int input)
 {
 #ifdef VM_X86_64
    CPUIDRegs regs;
-   __cpuid((int *)&regs, input);
+   __cpuid((unsigned int *)&regs, input);
    return regs.ebx;
 #else
    uint32 output;
@@ -354,7 +391,7 @@ __GET_ECX_FROM_CPUID(int input)
 {
 #ifdef VM_X86_64
    CPUIDRegs regs;
-   __cpuid((int *)&regs, input);
+   __cpuid((unsigned int *)&regs, input);
    return regs.ecx;
 #else
    uint32 output;
@@ -381,7 +418,7 @@ __GET_EDX_FROM_CPUID(int input)
 {
 #ifdef VM_X86_64
    CPUIDRegs regs;
-   __cpuid((int *)&regs, input);
+   __cpuid((unsigned int *)&regs, input);
    return regs.edx;
 #else
    uint32 output;
@@ -406,7 +443,7 @@ __GET_EDX_FROM_CPUID(int input)
 #ifdef VM_X86_64
 
 /*
- * No inline assembly in Win64. Implemented in bora/lib/misc in
+ * No inline assembly in Win64. Implemented in bora/lib/user in
  * cpuidMasm64.asm.
  */
 
@@ -440,11 +477,17 @@ __GET_EAX_FROM_CPUID4(int inputEcx)
 #endif // VM_X86_64
 
 #else // }
-#error
+#error 
 #endif
 
 #define CPUID_FOR_SIDE_EFFECTS() ((void)__GET_EAX_FROM_CPUID(0))
 
+static INLINE void
+__GET_CPUID4(int inputEcx, CPUIDRegs *regs)
+{
+   __GET_CPUID2(4, inputEcx, regs);
+}
+
 /* The first parameter is used as an rvalue and then as an lvalue. */
 #define GET_CPUID(_ax, _bx, _cx, _dx) { \
    CPUIDRegs regs;                      \
