@@ -163,17 +163,20 @@ Id_SetGid(gid_t egid)		// IN: new egid
 {
 #if defined(__APPLE__)
    Warning("XXXMACOS: implement %s\n", __func__);
+
    return -1;
 #elif defined(sun) || defined(__FreeBSD__)
    return setgid(egid);
 #else
    if (uid32) {
       int r = syscall(SYS_setgid32, egid);
+
       if (r != -1 || errno != ENOSYS) {
          return r;
       }
       uid32 = 0;
    }
+
    return syscall(SYS_setgid, egid);
 #endif
 }
@@ -206,14 +209,17 @@ Id_SetRESUid(uid_t uid,		// IN: new uid
 #elif defined(linux)
    if (uid32) {
       int r = syscall(SYS_setresuid32, uid, euid, suid);
+
       if (r != -1 || errno != ENOSYS) {
          return r;
       }
       uid32 = 0;
    }
+
    return syscall(SYS_setresuid, uid, euid, suid);
 #else
    Warning("XXX: implement %s\n", __func__);
+
    return -1;
 #endif
 }
@@ -247,14 +253,17 @@ Id_SetRESGid(gid_t gid,		// IN: new gid
 #elif defined(linux)
    if (uid32) {
       int r = syscall(SYS_setresgid32, gid, egid, sgid);
+
       if (r != -1 || errno != ENOSYS) {
          return r;
       }
       uid32 = 0;
    }
+
    return syscall(SYS_setresgid, gid, egid, sgid);
 #else
    Warning("XXX: implement %s\n", __func__);
+
    return -1;
 #endif
 }
@@ -292,11 +301,13 @@ Id_SetREUid(uid_t uid,		// IN: new uid
 #else
    if (uid32) {
       int r = syscall(SYS_setreuid32, uid, euid);
+
       if (r != -1 || errno != ENOSYS) {
          return r;
       }
       uid32 = 0;
    }
+
    return syscall(SYS_setreuid, uid, euid);
 #endif
 }
@@ -331,11 +342,13 @@ Id_SetREGid(gid_t gid,		// IN: new gid
 #else
    if (uid32) {
       int r = syscall(SYS_setregid32, gid, egid);
+
       if (r != -1 || errno != ENOSYS) {
          return r;
       }
       uid32 = 0;
    }
+
    return syscall(SYS_setregid, gid, egid);
 #endif
 }
@@ -383,6 +396,7 @@ IdAuthCreate(void)
     * euid or gid != egid?  Some callers may expect us to check
     * against euid, others may expect us to check against uid.
     */
+
    uid_t thread_uid;
    gid_t thread_gid;
    int ret;
@@ -394,27 +408,28 @@ IdAuthCreate(void)
        * We have per-thread UIDs in use, so Apple's authorization
        * APIs don't work.  Fork so we can use them.
        */
+
       return IdAuthCreateWithFork();
    } else {
       if (errno != ESRCH) {
-         Warning("%s: gettid failed, error %d.\n", __FUNCTION__, errno);
+         Warning("%s: gettid failed, error %d.\n", __func__, errno);
+
          return NULL;
       } else {
           // Per-thread identities are not in use in this thread.
          AuthorizationRef auth;
          OSStatus ret;
 
-         ret = AuthorizationCreate(NULL,
-                                   kAuthorizationEmptyEnvironment,
-                                   kAuthorizationFlagDefaults,
-                                   &auth);
+         ret = AuthorizationCreate(NULL, kAuthorizationEmptyEnvironment,
+                                   kAuthorizationFlagDefaults, &auth);
 
          if (ret == errAuthorizationSuccess) {
             return auth;
          } else {
             ASSERT_ON_COMPILE(sizeof ret == sizeof (int32));
             Warning("%s: AuthorizationCreate failed, error %d.\n",
-                    __FUNCTION__, (int32)ret);
+                    __func__, (int32)ret);
+
             return NULL;
          }
       }
@@ -539,10 +554,10 @@ IdAuthCreateWithFork(void)
           * Wait until the child can destroy its process ref to the auth
           * session.
           */
-         for (;;) {
-            ssize_t actual;
 
-            actual = read(fds[1], &buf, sizeof buf);
+         for (;;) {
+            ssize_t actual = read(fds[1], &buf, sizeof buf);
+
             ASSERT(actual <= sizeof buf);
             if (actual) {
                break;
@@ -555,6 +570,7 @@ IdAuthCreateWithFork(void)
        * o Destroys the child process ref to the Authorization session.
        * o Closes fds[0] and fds[1]
        */
+
       exit(0);
    }
 
@@ -593,9 +609,7 @@ IdAuthGet(void)
    if (UNLIKELY(Atomic_ReadPtr(&procAuth) == NULL)) {
       AuthorizationRef newProcAuth = IdAuthCreate();
 
-      if (Atomic_ReadIfEqualWritePtr(&procAuth,
-                                     NULL,
-                                     newProcAuth)) {
+      if (Atomic_ReadIfEqualWritePtr(&procAuth, NULL, newProcAuth)) {
          // Someone else snuck in before we did.  Free the new authorization.
          AuthorizationFree(newProcAuth, kAuthorizationFlagDefaults);
       }
@@ -663,16 +677,19 @@ Id_AuthGetExternal(size_t *size) // OUT
    ext = malloc(sizeof *ext);
    if (!ext) {
       Warning("Unable to allocate an AuthorizationExternalForm.\n");
+
       return NULL;
    }
 
    if (AuthorizationMakeExternalForm(auth, ext) != errAuthorizationSuccess) {
       Warning("AuthorizationMakeExternalForm() failed.\n");
       free(ext);
+
       return NULL;
    }
 
    *size = sizeof *ext;
+
    return ext;
 }
 
@@ -702,28 +719,29 @@ Id_AuthSet(void const *buf, // IN
    AuthorizationRef newProcAuth;
 
    AuthorizationExternalForm const *ext =
-      (AuthorizationExternalForm const *)buf;
+                                      (AuthorizationExternalForm const *)buf;
 
    if (!buf || size != sizeof *ext) {
       Warning("%s: Invalid argument.\n", __func__);
+
       return FALSE;
    }
 
    ASSERT(!Atomic_ReadPtr(&procAuth));
-   if (AuthorizationCreateFromExternalForm(ext, &newProcAuth)
-       != errAuthorizationSuccess) {
+   if (AuthorizationCreateFromExternalForm(ext,
+                                   &newProcAuth) != errAuthorizationSuccess) {
       Warning("AuthorizationCreateFromExternalForm failed.\n");
+
       return FALSE;
    }
 
-   if (Atomic_ReadIfEqualWritePtr(&procAuth,
-                                  NULL,
-                                  newProcAuth)) {
+   if (Atomic_ReadIfEqualWritePtr(&procAuth, NULL, newProcAuth)) {
       /*
        * This is meant to be called very early on in the life of the
        * process.  If someone else has snuck in an authorization,
        * we're toast.
        */
+
       NOT_IMPLEMENTED();
    }
 
@@ -766,7 +784,7 @@ Id_AuthCheck(char const *right,                // IN
    AuthorizationItem environmentItems[1] = { { 0 } };
    AuthorizationEnvironment environmentWithDescription = { 0 };
    const AuthorizationEnvironment *environment =
-      kAuthorizationEmptyEnvironment;
+                                              kAuthorizationEmptyEnvironment;
 
    auth = IdAuthGet();
    if (!auth) {
@@ -785,6 +803,7 @@ Id_AuthCheck(char const *right,                // IN
     * If the localized description is present, the API uses that
     * description and appends a space followed by the above string.
     */
+
    if (localizedDescription) {
       environmentItems[0].name = kAuthorizationEnvironmentPrompt;
       environmentItems[0].valueLength = strlen(localizedDescription);
@@ -799,8 +818,8 @@ Id_AuthCheck(char const *right,                // IN
     * the same AuthorizationRef?  Apple's documentation doesn't
     * actually say whether it is or is not.
     */
-   return AuthorizationCopyRights(auth, &rights,
-             environment,
+
+   return AuthorizationCopyRights(auth, &rights, environment,
              (showDialogIfNeeded ? kAuthorizationFlagInteractionAllowed |
                                    kAuthorizationFlagDefaults :
                                    kAuthorizationFlagDefaults) |
@@ -844,7 +863,6 @@ Id_BeginSuperUser(void)
 #else
       Id_SetRESUid((uid_t) -1, (uid_t) 0, (uid_t) -1); // effectively root
 #endif
-      return uid;
    }
 
    return uid;
