@@ -299,11 +299,14 @@ StrUtil_StrToInt(int32 *out,      // OUT
 
    val = strtol(str, &ptr, 0);
    *out = (int32)val;
+
    /*
-    * Input must be complete, no overflow, and value read must fit into 32 bits -
-    * both signed and unsigned values are accepted.
+    * Input must be complete, no overflow, and value read must fit into
+    * 32 bits - both signed and unsigned values are accepted.
     */
-   return *ptr == '\0' && errno != ERANGE && (val == (int32)val || val == (uint32)val);
+
+   return *ptr == '\0' && errno != ERANGE &&
+          (val == (int32)val || val == (uint32)val);
 }
 
 
@@ -338,11 +341,14 @@ StrUtil_StrToUint(uint32 *out,     // OUT
 
    val = strtoul(str, &ptr, 0);
    *out = (uint32)val;
+
    /*
-    * Input must be complete, no overflow, and value read must fit into 32 bits -
-    * both signed and unsigned values are accepted.
+    * Input must be complete, no overflow, and value read must fit into 32
+    * bits - both signed and unsigned values are accepted.
     */
-   return *ptr == '\0' && errno != ERANGE && (val == (uint32)val || val == (int32)val);
+
+   return *ptr == '\0' && errno != ERANGE &&
+          (val == (uint32)val || val == (int32)val);
 }
 
 
@@ -446,8 +452,8 @@ StrUtil_StrToSizet(size_t *out,     // OUT: The output value
  *
  *      Converts a string containing a measure of disk capacity (such as
  *      "100MB" or "1.5k") into an unadorned and primitive quantity of sector
- *      capacity. The comment before the switch statement describes the kinds of
- *      disk capacity expressible.
+ *      capacity. The comment before the switch statement describes the kinds
+ *      of disk capacity expressible.
  *
  * Results:
  *      TRUE if conversion was successful, FALSE otherwise.
@@ -504,21 +510,23 @@ StrUtil_CapacityToSectorType(SectorType *out,    // OUT: The output value
       quantity *= (double)(1 << shift);
    } else {
       /*
-       * No suffix, so multiply by the number of bytes per unit as specified by
-       * the caller.
+       * No suffix, so multiply by the number of bytes per unit as specified
+       * by the caller.
        */
+
       quantity *= (double)bytes;
    }
 
    /*
-    * Convert from "number of bytes" to "number of sectors", rounding up or down
-    * appropriately.
+    * Convert from "number of bytes" to "number of sectors", rounding up or
+    * down appropriately.
     *
-    * XXX: We should use DISKLIB_SECTOR_SIZE, but do we really want the disklib
-    * header dependencies in this file?
+    * XXX: We should use DISKLIB_SECTOR_SIZE, but do we really want the
+    * disklib header dependencies in this file?
     *
     */
    *out = (SectorType)((quantity + 256) / 512);
+
    return TRUE;
 }
 #endif
@@ -548,9 +556,10 @@ StrUtil_FormatSizeInBytesUnlocalized(uint64 size) // IN
    /*
     * XXX TODO, BUG 199661:
     * This is a direct copy of Msg_FormatSizeInBytes without localization.
-    * These two functions should ideally share the basic functionality, and just
-    * differ in the string localization
+    * These two functions should ideally share the basic functionality, and
+    * just differ in the string localization
     */
+
    char const *fmt;
    double sizeInSelectedUnit;
    unsigned int precision;
@@ -665,6 +674,7 @@ StrUtil_GetLongestLineLength(const char *buf,   //IN
        bufLength -= len;
        buf = next;
     }
+
     return longest;
 }
 
@@ -691,6 +701,7 @@ StrUtil_StartsWith(const char *s,      // IN
 {
    ASSERT(s != NULL);
    ASSERT(prefix != NULL);
+
    return Str_Strncmp(s, prefix, strlen(prefix)) == 0;
 }
 
@@ -717,6 +728,7 @@ StrUtil_CaselessStartsWith(const char *s,      // IN
 {
    ASSERT(s != NULL);
    ASSERT(prefix != NULL);
+
    return Str_Strncasecmp(s, prefix, strlen(prefix)) == 0;
 }
 
@@ -729,7 +741,8 @@ StrUtil_CaselessStartsWith(const char *s,      // IN
  *      Detects if a string ends with another string.
  *
  * Results:
- *      TRUE if string 'suffix' is found at the end of string 's', FALSE otherwise.
+ *      TRUE  if string 'suffix' is found at the end of string 's'
+ *      FALSE otherwise.
  *
  * Side effects:
  *      None.
@@ -789,6 +802,7 @@ StrUtil_VDynBufPrintf(DynBuf *b,        // IN/OUT
     * Arbitrary lower-limit on buffer size allocation, to avoid doing
     * many tiny enlarge operations.
     */
+
    const size_t minAllocSize = 128;
 
    while (1) {
@@ -831,7 +845,9 @@ StrUtil_VDynBufPrintf(DynBuf *b,        // IN/OUT
           * happens, believe it or not. See bug 253674.
           */
 
-         ASSERT(i + size == allocSize || ((char*)DynBuf_Get(b))[i + size] == '\0');
+         ASSERT(i + size == allocSize ||
+                ((char *)DynBuf_Get(b))[i + size] == '\0');
+
          DynBuf_SetSize(b, size + i);
          break;
 
@@ -843,6 +859,7 @@ StrUtil_VDynBufPrintf(DynBuf *b,        // IN/OUT
           */
 
          Bool success = DynBuf_Enlarge(b, size + minAllocSize);
+
          if (!success) {
             return FALSE;
          }
