@@ -75,14 +75,18 @@
 static void TimeUtilInit(TimeUtil_Date *d);
 static Bool TimeUtilLoadDate(TimeUtil_Date *d, const char *date);
 static Bool TimeUtilIsLeapYear(unsigned int year);
-static Bool TimeUtilIsValidDate(unsigned int year, unsigned int month, unsigned int day);
+static Bool TimeUtilIsValidDate(unsigned int year,
+                                unsigned int month,
+                                unsigned int day);
 
 
 /*
  * Function to guess Windows TZ Index and Name by using time offset in
  * a lookup table
  */
-static int TimeUtilFindIndexAndNameByUTCOffset(int utcStdOffMins, const char **ptzName);
+
+static int TimeUtilFindIndexAndNameByUTCOffset(int utcStdOffMins,
+                                               const char **ptzName);
 
 #if defined(_WIN32)
 /*
@@ -158,6 +162,7 @@ TimeUtil_StringToDate(TimeUtil_Date *d,  // IN/OUT
     * Reduce the string to a known and handled format: YYYYMMDD.
     * Then, passed to internal function TimeUtilLoadDate.
     */
+
    if (strlen(date) == 8) {
       /* 'YYYYMMDD' */
       return TimeUtilLoadDate(d, date);
@@ -318,6 +323,7 @@ TimeUtil_DaysSubtract(TimeUtil_Date *d,   // IN/OUT
     *   intentionally subtract an additional 2 days for each year
     *   and an additional 3 days.
     */
+
    dayCount = dayCount + 3 + 2 * (dayCount / 365);
 
    subYear = dayCount / 365;
@@ -344,6 +350,7 @@ TimeUtil_DaysSubtract(TimeUtil_Date *d,   // IN/OUT
     * making sure on the valid range, without checking
     * for leap year, etc.
     */
+
    if ((estDay > 28) && (estMonth == 2)) {
       estDay = 28;
    }
@@ -356,6 +363,7 @@ TimeUtil_DaysSubtract(TimeUtil_Date *d,   // IN/OUT
     * we also copy the time from the original argument in making
     * sure that it does not play role in the comparison.
     */
+
    estRes.hour = d->hour;
    estRes.minute = d->minute;
    estRes.second = d->second;
@@ -365,6 +373,7 @@ TimeUtil_DaysSubtract(TimeUtil_Date *d,   // IN/OUT
     * guaranteed to be lower than the actual result. Otherwise,
     * infinite loop will happen.
     */
+
    ASSERT(TimeUtil_DateLowerThan(&estRes, d));
 
    /*
@@ -372,6 +381,7 @@ TimeUtil_DaysSubtract(TimeUtil_Date *d,   // IN/OUT
     * Done by moving up (moving forward) the estimated a day at a time
     *    until they are the correct one (i.e. estDate + arg #day = arg date)
     */
+
    temp = estRes;
    TimeUtil_DaysAdd(&temp, nr);
    while (TimeUtil_DateLowerThan(&temp, d)) {
@@ -538,12 +548,15 @@ TimeUtil_DaysLeft(TimeUtil_Date const *d) // IN
    /* Get the current local date. */
    TimeUtil_PopulateWithCurrent(TRUE, &c);
 
-   /* Compute how many days we can add to the current date before reaching
-      the given date */
+   /*
+    * Compute how many days we can add to the current date before reaching
+    * the given date
+    */
+
    for (i = 0; i < MAX_DAYSLEFT + 1; i++) {
-      if (    c.year > d->year
-          || (c.year == d->year && c.month > d->month)
-          || (c.year == d->year && c.month == d->month && c.day >= d->day)) {
+      if ((c.year > d->year) ||
+          (c.year == d->year && c.month > d->month) ||
+          (c.year == d->year && c.month == d->month && c.day >= d->day)) {
          /* current date >= given date */
          return i;
       }
@@ -769,7 +782,8 @@ TimeUtil_GetTimeFormat(int64 utcTime,  // IN
       return NULL;
    }
 
-   if (!TimeUtil_UTCTimeToSystemTime((const __time64_t) utcTime, &systemTime)) {
+   if (!TimeUtil_UTCTimeToSystemTime((const __time64_t) utcTime,
+                                      &systemTime)) {
       return NULL;
    }
 
@@ -789,6 +803,7 @@ TimeUtil_GetTimeFormat(int64 utcTime,  // IN
    char *str;
    str = Util_SafeStrdup(ctime((const time_t *) &utcTime));
    str[strlen(str)-1] = '\0';
+
    return str;
 #endif // _WIN32
 }
@@ -842,14 +857,14 @@ TimeUtil_NtTimeToUnixTime(struct timespec *unixTime,   // OUT: Time in Unix form
       return -1;
    }
 
-#ifndef VM_X86_64
+#ifdef __i386__ // only for 32-bit x86
    Div643232(ntTime - UNIX_EPOCH, 10000000, &sec, &nsec);
    unixTime->tv_sec = sec;
    unixTime->tv_nsec = nsec * 100;
 #else
    unixTime->tv_sec = (ntTime - UNIX_EPOCH) / 10000000;
    unixTime->tv_nsec = ((ntTime - UNIX_EPOCH) % 10000000) * 100;
-#endif // VM_X86_64
+#endif // __i386__
 
    return 0;
 }
@@ -875,7 +890,7 @@ VmTimeType
 TimeUtil_UnixTimeToNtTime(struct timespec unixTime) // IN: Time in Unix format
 {
    return (VmTimeType)unixTime.tv_sec * 10000000 +
-      unixTime.tv_nsec / 100 + UNIX_EPOCH;
+                                          unixTime.tv_nsec / 100 + UNIX_EPOCH;
 }
 #endif // _WIN32 && N_PLAT_NLM
 
@@ -909,6 +924,7 @@ TimeUtil_UTCTimeToSystemTime(const __time64_t utcTime,   // IN
     * _localtime64 support years up through 3000.  At least it says
     * so.  I'm getting garbage only after reaching year 4408.
     */
+
    if (utcTime < 0 || utcTime > (60LL * 60 * 24 * 365 * (3000 - 1970))) {
       return FALSE;
    }
@@ -926,6 +942,7 @@ TimeUtil_UTCTimeToSystemTime(const __time64_t utcTime,   // IN
     * Main reason for this test is to cut out negative values _localtime64
     * likes to return for some inputs.
     */
+
    if (atmYear < 1601 || atmYear > 30827 ||
        atmMonth < 1 || atmMonth > 12 ||
        atm->tm_wday < 0 || atm->tm_wday > 6 ||
@@ -1016,6 +1033,7 @@ TimeUtil_GetLocalWindowsTimeZoneIndexAndName(char **ptzName)   // OUT: returning
           * Offset is to standard (no need for DST adjustment).
           * Negative is east of prime meridian.
           */
+
          utcStdOffMins = 0 - timezone/60;
       #else
          /*
@@ -1023,6 +1041,7 @@ TimeUtil_GetLocalWindowsTimeZoneIndexAndName(char **ptzName)   // OUT: returning
           * Offset is to local (need to adjust for DST).
           * Negative is west of prime meridian.
           */
+
          utcStdOffMins = tim.tm_gmtoff/60;
          if (tim.tm_isdst) {
             utcStdOffMins -= 60;
@@ -1037,7 +1056,8 @@ TimeUtil_GetLocalWindowsTimeZoneIndexAndName(char **ptzName)   // OUT: returning
 
    /* If we don't have it yet, look up windowsCode. */
    if (winTimeZoneIndex < 0) {
-      winTimeZoneIndex = TimeUtilFindIndexAndNameByUTCOffset(utcStdOffMins, &tzNameByUTCOffset);
+      winTimeZoneIndex = TimeUtilFindIndexAndNameByUTCOffset(utcStdOffMins,
+                                                         &tzNameByUTCOffset);
       if (winTimeZoneIndex >= 0) {
          *ptzName = Unicode_AllocWithUTF8(tzNameByUTCOffset);
       }
@@ -1113,6 +1133,7 @@ TimeUtilIsValidDate(unsigned int year,   // IN
    /*
     * Initialize the table
     */
+
    if (TimeUtilIsLeapYear(year)) {
       monthdays[2] = 29;
    } else {
@@ -1227,7 +1248,8 @@ TimeUtilLoadDate(TimeUtil_Date *d,  // IN/OUT
       return FALSE;
    }
 
-   if (!TimeUtilIsValidDate((unsigned int) year, (unsigned int) month, (unsigned int) day)) {
+   if (!TimeUtilIsValidDate((unsigned int) year, (unsigned int) month,
+                            (unsigned int) day)) {
       return FALSE;
    }
 
@@ -1404,9 +1426,7 @@ static int Win32TimeUtilLookupZoneIndex(const char* targetName)
                            "Windows NT\\"
                            "CurrentVersion\\"
                            "Time Zones",
-                           0,
-                           KEY_READ,
-                           &parentKey) != ERROR_SUCCESS) {
+                           0, KEY_READ, &parentKey) != ERROR_SUCCESS) {
       /* Failed to open registry */
       return (-1);
    }
@@ -1415,13 +1435,9 @@ static int Win32TimeUtilLookupZoneIndex(const char* targetName)
    keyIndex = 0;
    while (
          timeZoneIndex < 0 &&
-         Win32U_RegEnumKeyEx(parentKey,
-                             keyIndex,
-                             childKeyName,
-                             &childKeyLen,
+         Win32U_RegEnumKeyEx(parentKey, keyIndex, childKeyName, &childKeyLen,
                              0,0,0,0) == ERROR_SUCCESS) {
-
-      char* std;
+      char *std;
       DWORD stdSize;
 
       /* Open child key */
@@ -1431,28 +1447,25 @@ static int Win32TimeUtilLookupZoneIndex(const char* targetName)
       }
 
       /* Get size of "Std" value */
-      if (Win32U_RegQueryValueEx(childKey,
-                                 "Std", 0, 0,
+      if (Win32U_RegQueryValueEx(childKey, "Std", 0, 0,
                                  NULL, &stdSize) == ERROR_SUCCESS) {
 
          /* Get value of "Std" */
          std = (char*) calloc(stdSize+1, sizeof(char));
          if (std != NULL) {
-            if (Win32U_RegQueryValueEx(childKey,
-                                       "Std", 0, 0,
-                                       (LPBYTE) std, &stdSize) == ERROR_SUCCESS) {
+            if (Win32U_RegQueryValueEx(childKey, "Std", 0, 0, (LPBYTE) std,
+                                       &stdSize) == ERROR_SUCCESS) {
 
                /* Make sure there is at least one EOS */
                std[stdSize] = '\0';
 
                /* Is this the name we want? */
                if (!strcmp(std, targetName)) {
-
                   /* yes: look up value of "Index" */
                   DWORD val = 0;
                   DWORD valSize = sizeof(val);
-                  if (Win32U_RegQueryValueEx(childKey,
-                                             "Index", 0, 0,
+
+                  if (Win32U_RegQueryValueEx(childKey, "Index", 0, 0,
                                              (LPBYTE) &val,
                                              &valSize) == ERROR_SUCCESS) {
                      timeZoneIndex = val;
