@@ -24,9 +24,7 @@
  */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include "str.h"
-#include "log.h"
 
 
 /*
@@ -35,30 +33,18 @@
  * the functions of the real library, but not all.
  */
 #if !defined(NO_LOG_STUB)
-
-void
-LogV(uint32 unused,
-     const char *fmt,
-     va_list args)
-{
-   char *str;
-
-   str = Str_Vasprintf(NULL, fmt, args);
-   if (str != NULL) {
-      fputs(str, stderr);
-      free(str);
-   }
-}
-
-
 void
 Log(const char *fmt,
     ...)
 {
+   char *str;
    va_list args;
 
    va_start(args, fmt);
-   LogV(VMW_LOG_INFO, fmt, args);
+   str = Str_Vasprintf(NULL, fmt, args);
+   if (str != NULL) {
+      fputs(str, stderr);
+   }
    va_end(args);
 }
 #endif
