@@ -51,7 +51,6 @@
 #include "unityDebug.h"
 #include "dynxdr.h"
 #include "guestrpc/unityActive.h"
-#include "guestCaps.h"
 #include "appUtil.h"
 #include <stdio.h>
 
@@ -170,6 +169,8 @@ static UnityCommandElem unityCommandTable[] = {
    { UNITY_RPC_WINDOW_UNMINIMIZE, UnityPlatformUnminimizeWindow },
    { UNITY_RPC_WINDOW_MAXIMIZE, UnityPlatformMaximizeWindow },
    { UNITY_RPC_WINDOW_UNMAXIMIZE, UnityPlatformUnmaximizeWindow },
+   { UNITY_RPC_WINDOW_STICK, UnityPlatformStickWindow },
+   { UNITY_RPC_WINDOW_UNSTICK, UnityPlatformUnstickWindow },
    /* Add more commands and handlers above this. */
    { NULL, NULL }
 };
@@ -258,8 +259,9 @@ Unity_IsActive(void)
  */
 
 void
-Unity_Init(GuestApp_Dict *conf, // IN
-           int* blockedWnd)     // IN
+Unity_Init(GuestApp_Dict *conf,                                    // IN
+           int *blockedWnd,                                        // IN
+           DesktopSwitchCallbackManager *desktopSwitchCallbackMgr) // IN
 {
    Debug("Unity_Init\n");
 
@@ -283,7 +285,10 @@ Unity_Init(GuestApp_Dict *conf, // IN
    /*
     * Initialize the host-specific portion of the unity service.
     */
-   unity.up = UnityPlatformInit(&unity.tracker, &unity.updateChannel, blockedWnd);
+   unity.up = UnityPlatformInit(&unity.tracker,
+                                &unity.updateChannel,
+                                blockedWnd,
+                                desktopSwitchCallbackMgr);
 
    /*
     * Init our global dynbuf used to send results back.
@@ -380,6 +385,8 @@ Unity_InitBackdoor(struct RpcIn *rpcIn)   // IN
     */
 
    if (Unity_IsSupported()) {
+      UnityCommandElem *elem;
+
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_ENTER, UnityTcloEnter, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_GET_UPDATE_FULL, UnityTcloGetUpdate, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_GET_UPDATE_INCREMENTAL,
@@ -388,8 +395,6 @@ Unity_InitBackdoor(struct RpcIn *rpcIn)   // IN
                              UnityTcloGetWindowPath, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_SETTOP,
                              UnityTcloSetTopWindowGroup, NULL);
-      RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_CLOSE,
-                             UnityTcloWindowCommand, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_GET_WINDOW_CONTENTS,
                              UnityTcloGetWindowContents, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_GET_ICON_DATA,
@@ -400,24 +405,20 @@ Unity_InitBackdoor(struct RpcIn *rpcIn)   // IN
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_EXIT, UnityTcloExit, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_MOVE_RESIZE,
                              UnityTcloMoveResizeWindow, NULL);
-      RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_SHOW,
-                             UnityTcloWindowCommand, NULL);
-      RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_HIDE,
-                             UnityTcloWindowCommand, NULL);
-      RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_MINIMIZE,
-                             UnityTcloWindowCommand, NULL);
-      RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_UNMINIMIZE,
-                             UnityTcloWindowCommand, NULL);
-      RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_MAXIMIZE,
-                             UnityTcloWindowCommand, NULL);
-      RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_UNMAXIMIZE,
-                             UnityTcloWindowCommand, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_DESKTOP_CONFIG_SET,
                              UnityTcloSetDesktopConfig, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_DESKTOP_ACTIVE_SET,
                              UnityTcloSetDesktopActive, NULL);
       RpcIn_RegisterCallback(rpcIn, UNITY_RPC_WINDOW_DESKTOP_SET,
                              UnityTcloSetWindowDesktop, NULL);
+
+      /*
+       * Handle all of the UnityTcloWindowCommand RPCs at once.
+       */
+      for (elem = unityCommandTable; elem->name != NULL; elem++) {
+         RpcIn_RegisterCallback(rpcIn, elem->name, UnityTcloWindowCommand,
+                                NULL);
+      }
    }
 }
 
@@ -448,7 +449,9 @@ Unity_InitBackdoor(struct RpcIn *rpcIn)   // IN
 void
 Unity_SetActiveDnDDetWnd(UnityDnD *state)
 {
-   UnityPlatformSetActiveDnDDetWnd(unity.up, state);
+   if (unity.up != NULL) {
+      UnityPlatformSetActiveDnDDetWnd(unity.up, state);
+   }
 }
 
 
@@ -1873,12 +1876,6 @@ UnityTcloSetDesktopActive(char const **result,  // OUT
       goto error;
    }
 
-   /*
-    * Update the uwt with the new active desktop info.
-    */
-
-   UnityWindowTracker_ChangeActiveDesktop(&unity.tracker, desktopId);
-
    return RpcIn_SetRetVals(result, resultLen,
                            "",
                            TRUE);
@@ -1936,6 +1933,16 @@ UnityTcloSetWindowDesktop(char const **result,  // OUT
       goto error;
    }
 
+   /*
+    * Set the desktop id for this window in the tracker.
+    * We need to do this before moving the window since on MS Windows platforms
+    * moving the window will hide it and there's a danger that we may enumerate the
+    * hidden window before changing it's desktop ID. The Window tracker will ignore
+    * hidden windows on the current desktop - which ultimately can lead to this window
+    * being reaped from the tracker.
+    */
+   UnityWindowTracker_ChangeWindowDesktop(&unity.tracker, windowId, desktopId);
+
    /*
     * Call the platform specific function to move the window to the
     * specified desktop.
@@ -1946,8 +1953,6 @@ UnityTcloSetWindowDesktop(char const **result,  // OUT
       goto error;
    }
 
-   UnityWindowTracker_ChangeWindowDesktop(&unity.tracker, windowId, desktopId);
-
    return RpcIn_SetRetVals(result, resultLen,
                            "",
                            TRUE);
