@@ -49,9 +49,6 @@ static void USWindowUpdate(UnityPlatform *up,
 static UnitySpecialWindow *USWindowLookup(UnityPlatform *up, Window window);
 static void USWindowDestroy(UnityPlatform *up, UnitySpecialWindow *usw);
 
-static gboolean UnityPlatformHandleEvents(gboolean errorOccurred,
-                                          gboolean inputAvailable,
-                                          gpointer data);
 static void UnityPlatformProcessXEvent(UnityPlatform *up,
                                        const XEvent *xevent,
                                        Window realEventWindow);
@@ -63,10 +60,6 @@ static void USRootWindowsProcessEvent(UnityPlatform *up,
 static int UnityPlatformXErrorHandler(Display *dpy, XErrorEvent *xev);
 static UnitySpecialWindow *UnityPlatformMakeRootWindowsObject(UnityPlatform *up);
 
-static gboolean UnityPlatformHandleEventsGlib(GIOChannel *source,
-                                              GIOCondition condition,
-                                              gpointer data);
-
 static void UnityPlatformSendClientMessageFull(Display *d,
                                                Window destWindow,
                                                Window w,
@@ -83,11 +76,19 @@ static void UnityPlatformDnDSendClientMessage(UnityPlatform *up,
                                               int numItems,
                                               const void *data);
 
+static Bool GetRelevantWMWindow(UnityPlatform *up,
+                                UnityWindowId windowId,
+                                Window *wmWindow);
+static Bool SetWindowStickiness(UnityPlatform *up,
+                                UnityWindowId windowId,
+                                Bool wantSticky);
+
 static const GuestCapabilities platformUnityCaps[] = {
    UNITY_CAP_WORK_AREA,
    UNITY_CAP_START_MENU,
    UNITY_CAP_MULTI_MON,
-   UNITY_CAP_VIRTUAL_DESK
+   UNITY_CAP_VIRTUAL_DESK,
+   UNITY_CAP_STICKY_WINDOWS,
 };
 
 /*
@@ -136,9 +137,10 @@ UnityPlatformIsSupported(void)
  */
 
 UnityPlatform *
-UnityPlatformInit(UnityWindowTracker *tracker,          // IN
-                  UnityUpdateChannel *updateChannel,    // IN
-                  int *blockedWnd)                      // UNUSED
+UnityPlatformInit(UnityWindowTracker *tracker,                            // IN
+                  UnityUpdateChannel *updateChannel,                      // IN
+                  int *blockedWnd,                                        // IN, not used
+                  DesktopSwitchCallbackManager *desktopSwitchCallbackMgr) // IN, not used
 {
    UnityPlatform *up;
    char *displayName;
@@ -304,7 +306,7 @@ UnityPlatformCleanup(UnityPlatform *up) // IN
     * Caller should've called Unity_Exit first.
     */
    ASSERT(!up->isRunning);
-   ASSERT(!up->unityDisplayWatchID);
+   ASSERT(up->glibSource == NULL);
 
    if (up->specialWindows) {
       HashTable_Free(up->specialWindows);
@@ -765,12 +767,11 @@ UnityPlatformKillHelperThreads(UnityPlatform *up) // IN
    size_t numWindows;
 
    if (!up || !up->isRunning) {
-      ASSERT(!up->unityDisplayWatchID);
+      ASSERT(up->glibSource == NULL);
       return;
    }
 
-   g_source_remove(up->unityDisplayWatchID);
-   up->unityDisplayWatchID = 0;
+   UnityX11EventTeardownSource(up);
 
    up->desktopInfo.numDesktops = 0; // Zero means host has not set virtual desktop config
    UnityX11RestoreSystemSettings(up);
@@ -913,7 +914,7 @@ Bool
 UnityPlatformStartHelperThreads(UnityPlatform *up) // IN
 {
    ASSERT(up);
-   ASSERT(!up->unityDisplayWatchID);
+   ASSERT(up->glibSource == NULL);
 
    XSync(up->display, TRUE);
    up->rootWindows = UnityPlatformMakeRootWindowsObject(up);
@@ -962,15 +963,7 @@ UnityPlatformStartHelperThreads(UnityPlatform *up) // IN
     * Set up a callback in the glib main loop to listen for incoming X events on the
     * unity display connection.
     */
-   {
-      GIOChannel *unityDisplayChannel;
-      unityDisplayChannel = g_io_channel_unix_new(ConnectionNumber(up->display));
-      up->unityDisplayWatchID = g_io_add_watch(unityDisplayChannel,
-                                               G_IO_IN | G_IO_ERR | G_IO_HUP | G_IO_NVAL,
-                                               UnityPlatformHandleEventsGlib,
-                                               up);
-      g_io_channel_unref(unityDisplayChannel);
-   }
+   UnityX11EventEstablishSource(up);
 
    return TRUE;
 }
@@ -1174,42 +1167,7 @@ UnityPlatformUpdateWindowState(UnityPlatform *up,               // IN
 /*
  *-----------------------------------------------------------------------------
  *
- * UnityPlatformHandleEventsGlib --
- *
- *      Lets the UnityPlatform object know that new events are available to process.
- *      This implementation is used in Gtk+ 2.0 and greater.
- *
- * Results:
- *      TRUE if we should continue to process events from the display, FALSE otherwise.
- *
- * Side effects:
- *      None.
- *
- *-----------------------------------------------------------------------------
- */
-
-static gboolean
-UnityPlatformHandleEventsGlib(GIOChannel *source,     // IN
-                              GIOCondition condition, // IN
-                              gpointer data)          // IN
-{
-   gboolean errorOccurred = FALSE;
-   gboolean inputAvailable = FALSE;
-
-   if (condition & (G_IO_ERR | G_IO_HUP | G_IO_NVAL)) {
-      errorOccurred = TRUE;
-   } else if (condition & G_IO_IN) {
-      inputAvailable = TRUE;
-   }
-
-   return UnityPlatformHandleEvents(errorOccurred, inputAvailable, data);
-}
-
-
-/*
- *-----------------------------------------------------------------------------
- *
- * UnityPlatformHandleEvents --
+ * UnityX11HandleEvents --
  *
  *      Handle incoming events
  *
@@ -1222,10 +1180,8 @@ UnityPlatformHandleEventsGlib(GIOChannel *source,     // IN
  *-----------------------------------------------------------------------------
  */
 
-static gboolean
-UnityPlatformHandleEvents(gboolean errorOccurred,  // IN
-                          gboolean inputAvailable, // IN
-                          gpointer data)           // IN
+gboolean
+UnityX11HandleEvents(gpointer data) // IN
 {
    UnityPlatform *up = (UnityPlatform *) data;
    GList *incomingEvents = NULL;
@@ -1234,15 +1190,6 @@ UnityPlatformHandleEvents(gboolean errorOccurred,  // IN
    ASSERT(up);
    ASSERT(up->isRunning);
 
-   if (errorOccurred) {
-      /*
-       * XXX We should force an exit from unity mode here - our X connection just died.
-       */
-      return FALSE;
-   } else if (!inputAvailable) {
-      Panic("Unity event handler was invoked with no input and no error\n");
-   }
-
    Debug("Starting unity event handling\n");
    while (XEventsQueued(up->display, QueuedAfterFlush)) {
       /*
@@ -1937,10 +1884,7 @@ UnityPlatformSetTopWindowGroup(UnityPlatform *up,        // IN: Platform data
                                UnityWindowId *windows,   // IN: array of window ids
                                unsigned int windowCount) // IN: # of windows in the array
 {
-   UnityPlatformWindow *upw;
-   UnityPlatformWindow *prevupw = NULL;
-   Atom data[5] = {0,0,0,0,0};
-   XWindowChanges winch;
+   Window sibling = None;
    int i;
 
    ASSERT(up);
@@ -1948,13 +1892,12 @@ UnityPlatformSetTopWindowGroup(UnityPlatform *up,        // IN: Platform data
    ASSERT(windowCount);
 
    /*
-    * Restack everything top to bottom.
+    * Restack everything bottom to top.
     */
-   data[0] = 2; // Magic source indicator to give full control
-   winch.stack_mode = data[2] = Above; // First window will go at the top of everything
    for (i = 0; i < windowCount; i++) {
-      unsigned int valueMask = CWStackMode;
+      UnityPlatformWindow *upw;
       Window curWindow;
+      Atom data[5] = {0,0,0,0,0};
 
       upw = UPWindow_Lookup(up, windows[i]);
       if (!upw) {
@@ -1964,52 +1907,49 @@ UnityPlatformSetTopWindowGroup(UnityPlatform *up,        // IN: Platform data
       curWindow = upw->clientWindow ? upw->clientWindow : upw->toplevelWindow;
       UPWindow_SetUserTime(up, upw);
 
-      if (i == 0) {
-         if (UnityPlatformWMProtocolSupported(up, UNITY_X11_WM__NET_ACTIVE_WINDOW)) {
-            uint32 activeData[5] = {0,0,0,0,0};
-            Window focusWindow;
-            int revertState;
-
-            XGetInputFocus(up->display, &focusWindow, &revertState);
-            activeData[0] = 2; // Source indicator
-            activeData[1] = UnityPlatformGetServerTime(up);
-            activeData[2] = focusWindow;
-            UnityPlatformSendClientMessage(up, up->rootWindows->windows[0],
-                                           curWindow, up->atoms._NET_ACTIVE_WINDOW,
-                                           32, 5, data);
-         } else {
-            XSetInputFocus(up->display, curWindow, RevertToParent,
-                           UnityPlatformGetServerTime(up));
-         }
-      }
-
-      if (prevupw) {
-         valueMask |= CWSibling;
-         if (prevupw->clientWindow) {
-            winch.sibling = data[1] = prevupw->clientWindow;
-         } else {
-            winch.sibling = data[1] = prevupw->toplevelWindow;
-         }
-      } else {
-         winch.sibling = data[1] = None;
-      }
-
       if (UnityPlatformWMProtocolSupported(up, UNITY_X11_WM__NET_RESTACK_WINDOW)) {
+         data[0] = 2;           // Magic source indicator to give full control
+         data[1] = sibling;
+         data[2] = Above;
+
          UnityPlatformSendClientMessage(up, up->rootWindows->windows[0],
                                         curWindow,
                                         up->atoms._NET_RESTACK_WINDOW,
                                         32, 5, data);
       } else {
-         XReconfigureWMWindow(up->display,
-                              curWindow,
-                              0, valueMask, &winch);
+         XWindowChanges winch = {
+            .stack_mode = Above,
+            .sibling = sibling
+         };
+         unsigned int valueMask = CWStackMode;
+
+         if (sibling != None) {
+            valueMask |= CWSibling;
+         }
+
+         /*
+          * As of writing, Metacity doesn't support _NET_RESTACK_WINDOW and
+          * will block our attempt to raise a window unless it's active, so
+          * we activate the window first.
+          */
+         if (UnityPlatformWMProtocolSupported(up, UNITY_X11_WM__NET_ACTIVE_WINDOW)) {
+            data[0] = 2;           // Magic source indicator to give full control
+            data[1] = UnityPlatformGetServerTime(up);
+            data[2] = None;
+            UnityPlatformSendClientMessage(up, up->rootWindows->windows[0],
+                                           curWindow,
+                                           up->atoms._NET_ACTIVE_WINDOW,
+                                           32, 5, data);
+         }
+
+         XReconfigureWMWindow(up->display, upw->toplevelWindow, 0, valueMask, &winch);
       }
 
-      prevupw = upw;
-      data[2] = Below; // We want all other windows stacked below the new top window
-      winch.stack_mode = Below;
+      sibling = upw->toplevelWindow;
    }
 
+   XSync(up->display, False);
+
    return TRUE;
 }
 
@@ -2858,7 +2798,7 @@ UnityPlatformSetDesktopConfig(UnityPlatform *up,                             //
  *
  * UnityPlatformSetInitialDesktop --
  *
- *     Set a desktop specified by the desktop id as the initial state. 
+ *     Set a desktop specified by the desktop id as the initial state.
  *
  * Results:
  *     Returns TRUE if successful, and FALSE otherwise.
@@ -2902,6 +2842,12 @@ UnityPlatformSetDesktopActive(UnityPlatform *up,         // IN
 {
    ASSERT(up);
 
+   /*
+    * Update the uwt with the new active desktop info.
+    */
+
+   UnityWindowTracker_ChangeActiveDesktop(up->tracker, desktopId);
+
    if (desktopId >= up->desktopInfo.numDesktops) {
       return FALSE;
    }
@@ -3017,3 +2963,152 @@ Unity_LocalToUnityPoint(UnityPoint *unityPt, // IN/OUT
    unityPt->y = localPt->y;
 }
 
+
+/*
+ ******************************************************************************
+ * UnityPlatformStickWindow --                                           */ /**
+ *
+ * @brief "Stick" a window to the desktop.
+ *
+ * @param[in] up       Platform context.
+ * @param[in] windowId Operand window.
+ *
+ * @retval TRUE  Success.
+ * @retval FALSE Failure.
+ *
+ ******************************************************************************
+ */
+
+Bool
+UnityPlatformStickWindow(UnityPlatform *up,      // IN
+                         UnityWindowId windowId) // IN
+{
+   return SetWindowStickiness(up, windowId, TRUE);
+}
+
+
+/*
+ ******************************************************************************
+ * UnityPlatformUnstickWindow --                                         */ /**
+ *
+ * @brief "Unstick" a window from the desktop.
+ *
+ * @param[in] up       Platform context.
+ * @param[in] windowId Operand window.
+ *
+ * @retval TRUE  Success.
+ * @retval FALSE Failure.
+ *
+ ******************************************************************************
+ */
+
+Bool
+UnityPlatformUnstickWindow(UnityPlatform *up,      // IN
+                           UnityWindowId windowId) // IN
+{
+   return SetWindowStickiness(up, windowId, FALSE);
+}
+
+
+/*
+ ******************************************************************************
+ * Begin file-scope functions.
+ *
+ */
+
+
+/*
+ ******************************************************************************
+ * GetRelevantWMWindow --                                                */ /**
+ *
+ * @brief Given a UnityWindowId, return the X11 window relevant to WM operations.
+ *
+ * Starting with a Unity window, look for and return its associated
+ * clientWindow.  If there is no clientWindow, then return the top-level window.
+ *
+ * @param[in]  up        Unity/X11 context.
+ * @param[in]  windowId  Window search for.
+ * @param[out] wmWindow  Set to the relevant X11 window.
+ *
+ * @todo Consider exporting this for use in unityPlatformX11Window.c.
+ *
+ * @retval TRUE  Relevant window found and recorded in @a wmWindow.
+ * @retval FALSE Unable to find @a windowId.
+ *
+ ******************************************************************************
+ */
+
+static Bool
+GetRelevantWMWindow(UnityPlatform *up,          // IN
+                    UnityWindowId windowId,     // IN
+                    Window *wmWindow)           // OUT
+{
+   UnityPlatformWindow *upw;
+
+   ASSERT(up);
+
+   upw = UPWindow_Lookup(up, windowId);
+   if (!upw) {
+      return FALSE;
+   }
+
+   *wmWindow = upw->clientWindow ? upw->clientWindow : upw->toplevelWindow;
+   return TRUE;
+}
+
+
+/*
+ ******************************************************************************
+ * SetWindowStickiness --                                                */ /**
+ *
+ * @brief Sets or clears a window's sticky state.
+ *
+ * @param[in] up         Unity/X11 context.
+ * @param[in] windowId   Operand window.
+ * @param[in] wantSticky Set to TRUE to stick a window, FALSE to unstick it.
+ *
+ * @retval TRUE  Request successfully sent to X server.
+ * @retval FALSE Request failed.
+ *
+ ******************************************************************************
+ */
+
+static Bool
+SetWindowStickiness(UnityPlatform *up,          // IN
+                    UnityWindowId windowId,     // IN
+                    Bool wantSticky)            // IN
+{
+   GdkWindow *gdkWindow;
+   Window curWindow;
+
+   ASSERT(up);
+
+   if (!GetRelevantWMWindow(up, windowId, &curWindow)) {
+      Debug("%s: Lookup against window %#x failed.\n", __func__, windowId);
+      return FALSE;
+   }
+
+   gdkWindow = gdk_window_foreign_new(curWindow);
+   if (gdkWindow == NULL) {
+      Debug("%s: Unable to create Gdk window?! (%#x)\n", __func__, windowId);
+      return FALSE;
+   }
+
+   if (wantSticky) {
+      gdk_window_stick(gdkWindow);
+   } else {
+      gdk_window_unstick(gdkWindow);
+   }
+
+   gdk_flush();
+   g_object_unref(G_OBJECT(gdkWindow));
+
+   return TRUE;
+}
+
+
+/*
+ *
+ * End file-scope functions.
+ ******************************************************************************
+ */
